      subroutine segget(nseg)
c   gets source parameters, either by asking questions or by reading from
c   a file. on subsequent calls, loops through the parameters, loading
c   them (suitably modified) into common black eqparm. Once all parameters
c   have been looped through, starts over (to allow for accumulation and
c   looping in the calling programs).
c
c   source parameters passed in common block are:
c     slat, slong - N lat and E long of source (degrees); if locat is
c                   c, these are the coordinates of the center of the plane; if
c                   t, the coordinates of the center of the top edge; if
c                   o, the coordinates of the center of the surface trace
c                   (projected up-dip if need be)
c     depth       - depth of source (km) (mid-depth of plane)
c     str,dip,rake- strike and dip of fault, rake of motion
c                   (rake is -180 for rl strike-slip, 666 for normal)
c     al, aw      - length (horizontal) and width (down-dip) of fault (km)
c     slip        - fault slip (m)
c
      save rlat,rlong,dep,strike,
     1 sdip,rrak,rlen,width,slp,
     2 tloc,ifrst,ifile,ic
      character*1 locat,tloc,howget,depspc,not,nsize
      character*80 filnam
      dimension rlat(9000),rlong(9000),dep(9000),strike(9000),
     1 sdip(9000),rrak(9000),rlen(9000),width(9000),slp(9000),
     2 tloc(9000)
      common/eqparm/slat,slong,depth,str,dip,rake,al,aw,slip,locat
      data dr/.0174533/,defmu/3.3e10/
      data ifrst/0/
c*****************
c
c Start of actions on first call
c
c*****************
      if(ifrst.eq.0) then
        ifrst=1
        write(6,100)
 100    format(' Get fault parameters from a file? (y/n); ',$)
        idum=ffin(1,howget)
        if(howget.eq.'y') ifile=1
        if(howget.ne.'y') ifile=0
        if(howget.ne.'y') then
          write(6,102)
 102      format(' Specify fault location by center of plane (c), top',
     1     ' edge (t), or outcrop (o); ',$)
          idum = ffin(1,locat)
          write(6,104)
 104      format(' N lat and E long of fault; ',$)
          slat = ffin(1,not)
          slong = ffin(1,not)
          write(6,106)
 106      format(' Fault strike and dip; ',$)
          str = ffin(1,not)
          dip = ffin(1,not)
          write(6,108)
 108      format(' Specify fault depth by center of plane (c), or of',
     1     ' top edge (t); ',$)
          idum = ffin(1,depspc)
          write(6,110)
 110      format(' Depth (km) of fault; ',$)
          depth = ffin(1,not)
          write(6,112)
 112      format(' Rake of slip (-180 for rl s-s, 666 normal); ',$)
          rake = ffin(1,not)
 7        write(6,114)
 114      format(' Specify fault slip (s) or moment (m)?; ',$)
          idum = ffin(1,nsize)
          if(nsize.ne.'s'.and.nsize.ne.'m') go to 7
          write(6,116)
 116      format(' Fault dimensions (length [along-strike] by width'
     1    ,' [down-dip], km); ',$)
          fx = 1000*ffin(1,not)
          fy = 1000*ffin(1,not)
c adjust depth if necessary (note depth in km, fy in m)
          if(depspc.eq.'t') depth = depth + 0.5*fy*sin(dr*dip)/1000.
          if(nsize.eq.'s') then
            write(6,120)
 120        format(' Slip (m); ',$)
            slip = ffin(1,not)
            eqdisl = slip*fx*fy
            rmom = defmu*eqdisl
            wm = .66666*alog10(rmom) - 6.0
            write(6,122) rmom,wm
 122        format(' Moment is ',1Pg13.5,' or Mw ',0Pf5.2)
          endif
          if(nsize.eq.'m') then
            write(6,124)
 124        format(' Moment (n-m, or <0 for dyn-cm); ',$)
            rmom = ffin(1,not)
            if(rmom.le.0) rmom = -1.e-7*rmom
            wm = .66666*alog10(rmom) - 6.0
            write(6,122) rmom,wm
          endif
          smu = defmu
          eqdisl = rmom/smu
          slip = eqdisl/(fx*fy)
c  now scale fault dimensions to be in km, since this reduces
c  the risk of overflow (slip scaled in routine stpsub)
          al = fx/1000.
          aw = fy/1000.
          nseg=1
        else
c
c  read paramters from a file; note that fault segments are specified
c  by coordinates, not strike and length. The first set of parameters is
c  loaded into eqparm
c
          write(6,130)
 130      format(' File of fault segment parameters;; ',$)
          read(5,*) filnam
          lu=2
          open(lu,name=filnam)
          nseg=1
 13       read(lu,*,end=17) rlat1,rlong1,rlat2,rlong2,tloc(nseg),depspc,
     1       dep(nseg),width(nseg),sdip(nseg),slp(nseg),rrak(nseg)
          call topo(rlat1,rlong1,rlat2,rlong2,del,az)
          call topod(rlat1,rlong1,del/2,az,rlat(nseg),rlong(nseg))
          rlen(nseg)=del
          strike(nseg)=az
          if(depspc.eq.'t') dep(nseg) = dep(nseg) +
     1           0.5*width(nseg)*sin(dr*sdip(nseg))
          nseg=nseg+1
          go to 13
 17       nseg=nseg-1
          ic=1
          close(lu)
c  end of reading from a file (if there is only one fault segment read
c  from a file, load it into eqparm, to match the case where it is not
c  read from a file)
          slat = rlat(ic)
          slong= rlong(ic)
          depth= dep(ic)
          str  = strike(ic)
          dip  = sdip(ic)
          rake = rrak(ic)
          al   = rlen(ic)
          aw   = width(ic)
          slip = slp(ic)
          locat= tloc(ic)
          return
        endif
      endif
c*****************
c
c End of actions on first call
c
c*****************
c
c
c  load fault parameters into eqparm, starting with the first ones and
c  proceeding to later ones on each call--unless these parameters have
c  been input from the terminal, in which case just return
c
      if(ifile.eq.0) return
      slat = rlat(ic)
      slong= rlong(ic)
      depth= dep(ic)
      str  = strike(ic)
      dip  = sdip(ic)
      rake = rrak(ic)
      al   = rlen(ic)
      aw   = width(ic)
      slip = slp(ic)
      locat= tloc(ic)
      ic=ic+1
      if(ic.gt.nseg) ic=1
      return
      end
