      subroutine stpsub(rlat,rlong,e2,t2,d2)
c   for a given dislocation source with parameters specified in
c  common block eqparm, finds the strains, tilts, and  displacements at
c  a location with latitude rlat, longitude rlong (the half-space formulae
c  are used, so the source should not be too far from the receiver)
c
c   $$$calls topo,fdefor,stran,van
c
      save e1,t1,d1,e0,d0,t0,dr
      dimension e2(3),t2(3),d2(3)
      dimension e1(3),t1(3),d1(3)
      dimension e0(3),t0(3),d0(3)
c
c   source parameters are:
c     slat, slong - N lat and E long of source (degrees); if locat is
c                   c, these are the coordinates of the center of the plane; if
c                   t, the coordinates of the center of the top edge; if
c                   o, the coordinates of the center of the surface trace
c                   (projected up-dip if need be)
c     depth       - depth of source (km) (mid-depth of plane)
c     str,dip,rake- strike and dip of fault, rake of motion
c                   (rake is -180 for rl strike-slip)
c     al, aw      - length (horizontal) and width (down-dip) of fault (km)
c     slip        - fault slip (m)
c
c
      character*1 locat
      common/eqparm/slat,slong,depth,str,dip,rake,al,aw,slip,locat
      common/elascn/pr
      data dr/.0174533/
      pr=0.25
      do  i=1,3
        e2(i) = 0.
        d2(i) = 0.
        t2(i) = 0.
      enddo
      call topo(slat,slong,rlat,rlong,del,az)
c  compute coordinates in fault-centered system
      theta = str - az
      xl = del*cos(dr*theta)
      yl = del*sin(dr*theta)
c  if necessary, adjust for the means of specifying the fault location
c  (the depth already beeing set to the mid-depth)
      if((abs(abs(dip)-90.).gt.0.05).and.(locat.eq.'o'))
     1                 yl = yl + depth/tan(dr*dip)
      if(locat.eq.'t') yl = yl + .5*aw*cos(dr*dip)
c  scale slip to be in km. rake of 666 is fault opening
      if(rake.ne.666) then
       uh = slip*cos(dr*rake)/1000.
       uv = slip*sin(dr*rake)/1000.
       un = 0.
      elseif(rake.eq.666) then
       uh = 0.
       uv = 0.
       un = slip/1000.
       un = 0.
      endif
      call fdefor(depth,al,aw,dip,uh,uv,un,xl,yl,d0,t0,e0)
c  rotate motions into geographical coordinates (1 south, 2 east)
      rot = str + 180.
      call van(d0,rot,d1)
      d1(3) = d0(3)
      call van(t0,rot,t1)
      t1(3) = t0(3)
      call stran(e0,rot,e1)
c
c   scale to mm, nrad, nanostrain, and accumulate
c
      do i=1,3
        e2(i) = 1.e9*e1(i)
        d2(i) = 1.e6*d1(i)
        t2(i) = 1.e9*t1(i)
      enddo
      return
      end
