#define MAXLEN 300
#define TRUE   1
#define FALSE  0
#include <stdio.h>
#include <ctype.h>

double ffinc_(not)
char *not;
/* C replacement of RLP free-format input function. Differences are:
     1. This version ignores lines which contain no printable chars
     2. This version will accept any number of delimiters (spaces,
        tabs, or commas) between numbers, and in any combination.
     3. This version will not accept white space within numbers (the
        fortran version allows it after the e in e-format)

  written by D. C. Agnew Mar-Nov 1980    
  mod 7/85 dh: static'ed the buffer
  mod 2/86 dca: changed to accept printable nonalphanumeric characters
  
  version 2.0 - august 1985
  mod 6/05 dca to return double, have only one calling function
  '#' treated as comment character, flushes buffer of remainder of line
  */
{
double atof();
double value;
static char str[MAXLEN];		/* static'ed 7/85  dh */
static int ip,len;
short comment;				/* TRUE if '#' seen, else FALSE 8/85 */

do {
     if(ip==0)		/*get a new line*/
   	  len=lftch(str);
     while(str[ip]==' ' || str[ip]=='\t' || str[ip]==',')
          ip++;			/*skip initial white space at start of line*/
     value=atof(&str[ip]);
     *not = garchk(&str[ip]); 	/*look for garbage characters*/
     if (*not == '#') comment = TRUE;	/* note comment  8/85 */
     else {
       ip = ip + ndlim(&str[ip]); /* else set pointer to after delimiter*/
       comment = FALSE;		  /* and clear comment flag */
       } /* else */

     if(ip>=len || comment)	/* reached end of line or comment; */
       ip = 0;			/* flush buffer in any case */

     } while (comment);

return(value);
}

lftch(s)
/*returns contents of a line in s, with its length as the value, */
/*unless the line is useless (no printable chars), in which case it */
/* asks for another */
char s[];
{
int c,i,flag;
do{
   i=0;
   flag=0;
   while(i<MAXLEN && (c=getchar())!=EOF && c!='\n'){	/*get character*/
      s[i++]=c;		/*put it in string*/
      if(isprint(c))
         flag=1;		/*found a useful (?) character*/
   }
/*out of characters - put null on end*/
   if(c=='\n'){
      s[i]=c;
      s[i+1]='\0';
   }
   else
      s[i]='\0';
} while(flag==0);		/*loop on empty string*/
return(i);		/*length is to end or newline, whichever is first*/
}


ndlim(s)
char s[];
/*returns distance from start of string to first nondelimiter following*/
/*a delimiter which follows a nondelimiter*/
{
int i, flag=0;
for(i=0;;i++){		/*scan through string*/
   if(s[i]=='\n' || s[i]=='\0')		/*exit at once for eof or newline*/
      return(i);
   else if  ((s[i]!=' ' && s[i]!='\t' && s[i]!=',') && flag==0)	/*nondelimiter*/
      flag = 1;
   else if ((s[i]==' ' || s[i]=='\t' || s[i]==',') && flag == 1)
      flag=2;
   else if  ((s[i]!=' ' && s[i]!='\t' && s[i]!=',') && flag==2)	/*nondelimiter*/
      return(i);		/*found delimiter after a nondelimiter*/
}
}


garchk(s)
/* looks through a string supposed to represent a number,
   and if something is wrong returns the first bad character,
   otherwise returns a '0' */

char s[];
{
int i=0, idec=0;

if(s[i]=='+' || s[i]=='-'){	/*have a sign*/
   if(isdigit(s[i+1]))		/*followed by digit - OK*/
      i++;
   else if(s[i+1]=='.' && isdigit(s[i+2])){ 	/*followed by dp followed by digit - OK*/
      i+=2;
      idec=1;
   }
   else
      return(s[i]);		/*not OK*/
}
while(isdigit(s[i]))		/*scan through digits*/
   i++;
if(s[i]=='.'){			/*found a decimal point*/
   if(idec==1)
      return(s[i]);		/*not the first one - not OK*/
   i++;				/*otherwise move to next character*/
   while(isdigit(s[i]))
      i++;			/*and scan any more digits*/
}
/* now at end of digit string - check end or go to exponent part*/
if(isspace(s[i]) || s[i]==',')
   return('0');			/*legal terminator*/
else if(s[i]!='e' && s[i]!='E')
   return(s[i]);		/*not an exponent*/
else if(s[i+1]!='+' && s[i+1]!='-' && !isdigit(s[i+1]))
   return(s[i]);		/*e is present, but not followed by anything sensible*/
i++;				/*start looking at e-part*/
if(s[i]=='+' || s[i]=='-'){
   if(isdigit(s[i+1]))
      i++;			/*sign is followed by digit-OK*/
   else
      return(s[i-1]);		/*it isnt - return e*/
}
while(isdigit(s[i]))
   i++;				/*scan through digits in exponent*/
if(isspace(s[i]) || s[i]==',')
   return('0');			/*legal terminator*/
else
   return(s[i]);
}
